returns a data frame of modules available in the LISS Data Archive. if
a blueprint has already been cached (via liss_blueprint()), the module
list is derived from the cache; otherwise the archive index page is
scraped directly.
returns a data frame of modules available in the LISS Data Archive. if
a blueprint has already been cached (via liss_blueprint()), the module
list is derived from the cache; otherwise the archive index page is
scraped directly.