Skip to contents

presents a series of interactive menus to choose which modules, waves, and file types to include in a download. the result can be passed directly to liss_download().

Usage

liss_select()

Value

a tibble suitable for liss_download(), or NULL if the user cancels at any step.

Examples

if (FALSE) { # \dontrun{
selection <- liss_select()
liss_download(selection)
} # }