downloads the files described in a selection tibble (typically produced
by liss_select()) to a local directory. requires an active session
established by liss_login().
Arguments
- .hosted
a tibble with at least columns
module,wave,file, andpath, as returned byliss_select()orget_hosted_files(). ifNULL, callsget_hosted_files()internally.- .dir
character. local directory to save files to. created automatically if it does not exist.
- .modules
optional character or integer vector to filter by module.
- .waves
optional integer vector to filter by wave number.
- .unzip
logical. if
TRUE(the default), ZIP files are extracted and the archive is removed.
Examples
if (FALSE) { # \dontrun{
liss_login()
selection <- liss_select()
liss_download(selection)
} # }