Skip to contents

verifies the cached session by attempting to download a random data file from the archive. returns FALSE if the session has expired or was never established.

Usage

liss_is_logged_in()

Value

logical scalar.

Examples

if (FALSE) { # \dontrun{
liss_login()
liss_is_logged_in()
} # }